@@ -11,12 +11,9 @@ source "${BASH_SOURCE%/*}/../unix/InstallFromCompressedFileFromURL.sh"
 # shellcheck source=../unix/SetEnvVar.sh
 source "${BASH_SOURCE%/*}/../unix/SetEnvVar.sh"
 
-# Commit c5039e158d20e85d4d8a2dee3160533d627b839a is the latest one in 6.0 branch. 
-# When using the latest commit we will also get fix for https://fftrac-bg.ffmpeg.org/ticket/10405
-# Should be changed to official release as soon as possible!
-version="c5039e158d20e85d4d8a2dee3160533d627b839a"
+version="n6.1"
 url_public="https://github.com/FFmpeg/FFmpeg/archive/$version.tar.gz"
-sha1="4e13a26d3be7ac4d69201a6aa0accd734b24b3c4"
+sha1="1feb946476f3076a9b38c97ca0d8b69e1826049c"
 url_cached="http://ci-files01-hki.ci.qt.io/input/ffmpeg/$version.tar.gz"
 ffmpeg_name="FFmpeg-$version"
 
